cli

package
v1.0.29 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package cli exposes public entry points for the DWS CLI so that external overlay modules can embed and launch the CLI after customising edition hooks.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() int

Execute runs the root CLI command and returns the process exit code.

func MCPIdentityHeaders added in v1.0.9

func MCPIdentityHeaders() map[string]string

MCPIdentityHeaders returns HTTP headers aligned with MCP tool calls (identity + edition merge). Overlays may pass this to auxiliary clients.

func SetVersion

func SetVersion(v, buildTime, gitCommit string)

SetVersion overrides the version, build time and git commit strings that are displayed by `dws version` and `dws --version`. Typically called by overlay main.go with values injected via ldflags.

Types

This section is empty.

Jump to